# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ApiDestinationHttpApiParameters',
    'ConnectionAuthParameters',
    'ConnectionAuthParametersApiKeyAuthParameters',
    'ConnectionAuthParametersBasicAuthParameters',
    'ConnectionAuthParametersOauthParameters',
    'ConnectionAuthParametersOauthParametersClientParameters',
    'ConnectionAuthParametersOauthParametersOauthHttpParameters',
    'ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter',
    'ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter',
    'ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter',
    'ConnectionNetworkParameters',
    'RuleTarget',
    'RuleTargetDeadLetterQueue',
    'RuleTargetParamList',
    'GetEventBusesBusResult',
    'GetEventSourcesSourceResult',
    'GetRulesRuleResult',
    'GetRulesRuleTargetResult',
]

@pulumi.output_type
class ApiDestinationHttpApiParameters(dict):
    def __init__(__self__, *,
                 endpoint: str,
                 method: str):
        """
        :param str endpoint: The endpoint of the API destination.
        :param str method: The HTTP request method. Valid values: `GET`, `POST`, `HEAD`, `DELETE`, `PUT`, `PATCH`.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "method", method)

    @property
    @pulumi.getter
    def endpoint(self) -> str:
        """
        The endpoint of the API destination.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter
    def method(self) -> str:
        """
        The HTTP request method. Valid values: `GET`, `POST`, `HEAD`, `DELETE`, `PUT`, `PATCH`.
        """
        return pulumi.get(self, "method")


@pulumi.output_type
class ConnectionAuthParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiKeyAuthParameters":
            suggest = "api_key_auth_parameters"
        elif key == "authorizationType":
            suggest = "authorization_type"
        elif key == "basicAuthParameters":
            suggest = "basic_auth_parameters"
        elif key == "oauthParameters":
            suggest = "oauth_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 api_key_auth_parameters: Optional['outputs.ConnectionAuthParametersApiKeyAuthParameters'] = None,
                 authorization_type: Optional[str] = None,
                 basic_auth_parameters: Optional['outputs.ConnectionAuthParametersBasicAuthParameters'] = None,
                 oauth_parameters: Optional['outputs.ConnectionAuthParametersOauthParameters'] = None):
        """
        :param 'ConnectionAuthParametersApiKeyAuthParametersArgs' api_key_auth_parameters: The parameters that are configured for API key authentication. See `api_key_auth_parameters` below.
        :param str authorization_type: The type of the authentication. Valid values: `API_KEY_AUTH`, `BASIC_AUTH`, `OAUTH_AUTH`.
        :param 'ConnectionAuthParametersBasicAuthParametersArgs' basic_auth_parameters: The parameters that are configured for basic authentication. See `basic_auth_parameters` below.
        :param 'ConnectionAuthParametersOauthParametersArgs' oauth_parameters: The parameters that are configured for OAuth authentication. See `oauth_parameters` below.
        """
        if api_key_auth_parameters is not None:
            pulumi.set(__self__, "api_key_auth_parameters", api_key_auth_parameters)
        if authorization_type is not None:
            pulumi.set(__self__, "authorization_type", authorization_type)
        if basic_auth_parameters is not None:
            pulumi.set(__self__, "basic_auth_parameters", basic_auth_parameters)
        if oauth_parameters is not None:
            pulumi.set(__self__, "oauth_parameters", oauth_parameters)

    @property
    @pulumi.getter(name="apiKeyAuthParameters")
    def api_key_auth_parameters(self) -> Optional['outputs.ConnectionAuthParametersApiKeyAuthParameters']:
        """
        The parameters that are configured for API key authentication. See `api_key_auth_parameters` below.
        """
        return pulumi.get(self, "api_key_auth_parameters")

    @property
    @pulumi.getter(name="authorizationType")
    def authorization_type(self) -> Optional[str]:
        """
        The type of the authentication. Valid values: `API_KEY_AUTH`, `BASIC_AUTH`, `OAUTH_AUTH`.
        """
        return pulumi.get(self, "authorization_type")

    @property
    @pulumi.getter(name="basicAuthParameters")
    def basic_auth_parameters(self) -> Optional['outputs.ConnectionAuthParametersBasicAuthParameters']:
        """
        The parameters that are configured for basic authentication. See `basic_auth_parameters` below.
        """
        return pulumi.get(self, "basic_auth_parameters")

    @property
    @pulumi.getter(name="oauthParameters")
    def oauth_parameters(self) -> Optional['outputs.ConnectionAuthParametersOauthParameters']:
        """
        The parameters that are configured for OAuth authentication. See `oauth_parameters` below.
        """
        return pulumi.get(self, "oauth_parameters")


@pulumi.output_type
class ConnectionAuthParametersApiKeyAuthParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiKeyName":
            suggest = "api_key_name"
        elif key == "apiKeyValue":
            suggest = "api_key_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersApiKeyAuthParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersApiKeyAuthParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersApiKeyAuthParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 api_key_name: Optional[str] = None,
                 api_key_value: Optional[str] = None):
        """
        :param str api_key_name: The name of the API key.
        :param str api_key_value: The value of the API key.
        """
        if api_key_name is not None:
            pulumi.set(__self__, "api_key_name", api_key_name)
        if api_key_value is not None:
            pulumi.set(__self__, "api_key_value", api_key_value)

    @property
    @pulumi.getter(name="apiKeyName")
    def api_key_name(self) -> Optional[str]:
        """
        The name of the API key.
        """
        return pulumi.get(self, "api_key_name")

    @property
    @pulumi.getter(name="apiKeyValue")
    def api_key_value(self) -> Optional[str]:
        """
        The value of the API key.
        """
        return pulumi.get(self, "api_key_value")


@pulumi.output_type
class ConnectionAuthParametersBasicAuthParameters(dict):
    def __init__(__self__, *,
                 password: Optional[str] = None,
                 username: Optional[str] = None):
        """
        :param str password: The password for basic authentication.
        :param str username: The username for basic authentication.
        """
        if password is not None:
            pulumi.set(__self__, "password", password)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def password(self) -> Optional[str]:
        """
        The password for basic authentication.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> Optional[str]:
        """
        The username for basic authentication.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class ConnectionAuthParametersOauthParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "authorizationEndpoint":
            suggest = "authorization_endpoint"
        elif key == "clientParameters":
            suggest = "client_parameters"
        elif key == "httpMethod":
            suggest = "http_method"
        elif key == "oauthHttpParameters":
            suggest = "oauth_http_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersOauthParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersOauthParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersOauthParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 authorization_endpoint: Optional[str] = None,
                 client_parameters: Optional['outputs.ConnectionAuthParametersOauthParametersClientParameters'] = None,
                 http_method: Optional[str] = None,
                 oauth_http_parameters: Optional['outputs.ConnectionAuthParametersOauthParametersOauthHttpParameters'] = None):
        """
        :param str authorization_endpoint: The IP address of the authorized endpoint.
        :param 'ConnectionAuthParametersOauthParametersClientParametersArgs' client_parameters: The parameters that are configured for the client. See `client_parameters` below.
        :param str http_method: The HTTP request method. Valid values: `GET`, `POST`, `HEAD`, `DELETE`, `PUT`, `PATCH`.
        :param 'ConnectionAuthParametersOauthParametersOauthHttpParametersArgs' oauth_http_parameters: The request parameters that are configured for OAuth authentication. See `oauth_http_parameters` below.
        """
        if authorization_endpoint is not None:
            pulumi.set(__self__, "authorization_endpoint", authorization_endpoint)
        if client_parameters is not None:
            pulumi.set(__self__, "client_parameters", client_parameters)
        if http_method is not None:
            pulumi.set(__self__, "http_method", http_method)
        if oauth_http_parameters is not None:
            pulumi.set(__self__, "oauth_http_parameters", oauth_http_parameters)

    @property
    @pulumi.getter(name="authorizationEndpoint")
    def authorization_endpoint(self) -> Optional[str]:
        """
        The IP address of the authorized endpoint.
        """
        return pulumi.get(self, "authorization_endpoint")

    @property
    @pulumi.getter(name="clientParameters")
    def client_parameters(self) -> Optional['outputs.ConnectionAuthParametersOauthParametersClientParameters']:
        """
        The parameters that are configured for the client. See `client_parameters` below.
        """
        return pulumi.get(self, "client_parameters")

    @property
    @pulumi.getter(name="httpMethod")
    def http_method(self) -> Optional[str]:
        """
        The HTTP request method. Valid values: `GET`, `POST`, `HEAD`, `DELETE`, `PUT`, `PATCH`.
        """
        return pulumi.get(self, "http_method")

    @property
    @pulumi.getter(name="oauthHttpParameters")
    def oauth_http_parameters(self) -> Optional['outputs.ConnectionAuthParametersOauthParametersOauthHttpParameters']:
        """
        The request parameters that are configured for OAuth authentication. See `oauth_http_parameters` below.
        """
        return pulumi.get(self, "oauth_http_parameters")


@pulumi.output_type
class ConnectionAuthParametersOauthParametersClientParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "clientId":
            suggest = "client_id"
        elif key == "clientSecret":
            suggest = "client_secret"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersOauthParametersClientParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersOauthParametersClientParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersOauthParametersClientParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 client_id: Optional[str] = None,
                 client_secret: Optional[str] = None):
        """
        :param str client_id: The ID of the client.
        :param str client_secret: The AccessKey secret of the client.
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[str]:
        """
        The ID of the client.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[str]:
        """
        The AccessKey secret of the client.
        """
        return pulumi.get(self, "client_secret")


@pulumi.output_type
class ConnectionAuthParametersOauthParametersOauthHttpParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bodyParameters":
            suggest = "body_parameters"
        elif key == "headerParameters":
            suggest = "header_parameters"
        elif key == "queryStringParameters":
            suggest = "query_string_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersOauthParametersOauthHttpParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 body_parameters: Optional[Sequence['outputs.ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter']] = None,
                 header_parameters: Optional[Sequence['outputs.ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter']] = None,
                 query_string_parameters: Optional[Sequence['outputs.ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter']] = None):
        """
        :param Sequence['ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameterArgs'] body_parameters: The parameters that are configured for the request body. See `body_parameters` below.
        :param Sequence['ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameterArgs'] header_parameters: The parameters that are configured for the request header. See `header_parameters` below.
        :param Sequence['ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameterArgs'] query_string_parameters: The parameters that are configured for the request path. See `query_string_parameters` below.
        """
        if body_parameters is not None:
            pulumi.set(__self__, "body_parameters", body_parameters)
        if header_parameters is not None:
            pulumi.set(__self__, "header_parameters", header_parameters)
        if query_string_parameters is not None:
            pulumi.set(__self__, "query_string_parameters", query_string_parameters)

    @property
    @pulumi.getter(name="bodyParameters")
    def body_parameters(self) -> Optional[Sequence['outputs.ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter']]:
        """
        The parameters that are configured for the request body. See `body_parameters` below.
        """
        return pulumi.get(self, "body_parameters")

    @property
    @pulumi.getter(name="headerParameters")
    def header_parameters(self) -> Optional[Sequence['outputs.ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter']]:
        """
        The parameters that are configured for the request header. See `header_parameters` below.
        """
        return pulumi.get(self, "header_parameters")

    @property
    @pulumi.getter(name="queryStringParameters")
    def query_string_parameters(self) -> Optional[Sequence['outputs.ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter']]:
        """
        The parameters that are configured for the request path. See `query_string_parameters` below.
        """
        return pulumi.get(self, "query_string_parameters")


@pulumi.output_type
class ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isValueSecret":
            suggest = "is_value_secret"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParametersBodyParameter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 is_value_secret: Optional[str] = None,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str is_value_secret: Specifies whether to enable authentication.
        :param str key: The key of the request path.
        :param str value: The key of the request path.
        """
        if is_value_secret is not None:
            pulumi.set(__self__, "is_value_secret", is_value_secret)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="isValueSecret")
    def is_value_secret(self) -> Optional[str]:
        """
        Specifies whether to enable authentication.
        """
        return pulumi.get(self, "is_value_secret")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of the request path.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The key of the request path.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isValueSecret":
            suggest = "is_value_secret"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParametersHeaderParameter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 is_value_secret: Optional[str] = None,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str is_value_secret: Specifies whether to enable authentication.
        :param str key: The key of the request path.
        :param str value: The key of the request path.
        """
        if is_value_secret is not None:
            pulumi.set(__self__, "is_value_secret", is_value_secret)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="isValueSecret")
    def is_value_secret(self) -> Optional[str]:
        """
        Specifies whether to enable authentication.
        """
        return pulumi.get(self, "is_value_secret")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of the request path.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The key of the request path.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isValueSecret":
            suggest = "is_value_secret"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionAuthParametersOauthParametersOauthHttpParametersQueryStringParameter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 is_value_secret: Optional[str] = None,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str is_value_secret: Specifies whether to enable authentication.
        :param str key: The key of the request path.
        :param str value: The key of the request path.
        """
        if is_value_secret is not None:
            pulumi.set(__self__, "is_value_secret", is_value_secret)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="isValueSecret")
    def is_value_secret(self) -> Optional[str]:
        """
        Specifies whether to enable authentication.
        """
        return pulumi.get(self, "is_value_secret")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of the request path.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The key of the request path.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ConnectionNetworkParameters(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "networkType":
            suggest = "network_type"
        elif key == "securityGroupId":
            suggest = "security_group_id"
        elif key == "vpcId":
            suggest = "vpc_id"
        elif key == "vswitcheId":
            suggest = "vswitche_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionNetworkParameters. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionNetworkParameters.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionNetworkParameters.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 network_type: str,
                 security_group_id: Optional[str] = None,
                 vpc_id: Optional[str] = None,
                 vswitche_id: Optional[str] = None):
        """
        :param str network_type: The network type. Valid values: `PublicNetwork`, `PrivateNetwork`. **NOTE:** If you set `network_type` to `PrivateNetwork`, you must configure `vpc_id`, `vswitche_id`, and `security_group_id`.
        :param str security_group_id: The ID of the security group.
        :param str vpc_id: The ID of the VPC.
        :param str vswitche_id: The ID of the VSwitch.
        """
        pulumi.set(__self__, "network_type", network_type)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitche_id is not None:
            pulumi.set(__self__, "vswitche_id", vswitche_id)

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> str:
        """
        The network type. Valid values: `PublicNetwork`, `PrivateNetwork`. **NOTE:** If you set `network_type` to `PrivateNetwork`, you must configure `vpc_id`, `vswitche_id`, and `security_group_id`.
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[str]:
        """
        The ID of the security group.
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitcheId")
    def vswitche_id(self) -> Optional[str]:
        """
        The ID of the VSwitch.
        """
        return pulumi.get(self, "vswitche_id")


@pulumi.output_type
class RuleTarget(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "paramLists":
            suggest = "param_lists"
        elif key == "targetId":
            suggest = "target_id"
        elif key == "deadLetterQueue":
            suggest = "dead_letter_queue"
        elif key == "pushRetryStrategy":
            suggest = "push_retry_strategy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleTarget. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleTarget.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleTarget.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 endpoint: str,
                 param_lists: Sequence['outputs.RuleTargetParamList'],
                 target_id: str,
                 type: str,
                 dead_letter_queue: Optional['outputs.RuleTargetDeadLetterQueue'] = None,
                 push_retry_strategy: Optional[str] = None):
        """
        :param str endpoint: The endpoint of the event target.
        :param Sequence['RuleTargetParamListArgs'] param_lists: The parameters that are configured for the event target. See `param_list` below.
        :param str target_id: The ID of the custom event target.
        :param str type: The type of the event target. Valid values: `acs.alikafka`, `acs.api.destination`, `acs.arms.loki`, `acs.datahub`, `acs.dingtalk`, `acs.eventbridge`, `acs.eventbridge.olap`, `acs.eventbus.SLSCloudLens`, `acs.fc.function`, `acs.fnf`, `acs.k8s`, `acs.mail`, `acs.mns.queue`, `acs.mns.topic`, `acs.openapi`, `acs.rabbitmq`, `acs.rds.mysql`, `acs.rocketmq`, `acs.sae`, `acs.sls`, `acs.sms`, `http`,`https` and `mysql`.
               **NOTE:** From version 1.208.1, `type` can be set to `acs.alikafka`, `acs.api.destination`, `acs.arms.loki`, `acs.datahub`, `acs.eventbridge.olap`, `acs.eventbus.SLSCloudLens`, `acs.fnf`, `acs.k8s`, `acs.openapi`, `acs.rds.mysql`, `acs.sae`, `acs.sls`, `mysql`.
        :param 'RuleTargetDeadLetterQueueArgs' dead_letter_queue: The dead letter queue. Events that are not processed or exceed the number of retries will be written to the dead letter. Support message service MNS and message queue RocketMQ. See `dead_letter_queue` below.
        :param str push_retry_strategy: The retry policy that is used to push the event. Valid values:
               - `BACKOFF_RETRY`: Backoff retry. The request can be retried up to three times. The interval between two consecutive retries is a random value between 10 and 20 seconds.
               - `EXPONENTIAL_DECAY_RETRY`: Exponential decay retry. The request can be retried up to 176 times. The interval between two consecutive retries exponentially increases to 512 seconds, and the total retry time is one day. The specific retry intervals are 1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 512, ..., and 512 seconds, including a maximum of one hundred and sixty-seven 512 seconds in total.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "param_lists", param_lists)
        pulumi.set(__self__, "target_id", target_id)
        pulumi.set(__self__, "type", type)
        if dead_letter_queue is not None:
            pulumi.set(__self__, "dead_letter_queue", dead_letter_queue)
        if push_retry_strategy is not None:
            pulumi.set(__self__, "push_retry_strategy", push_retry_strategy)

    @property
    @pulumi.getter
    def endpoint(self) -> str:
        """
        The endpoint of the event target.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter(name="paramLists")
    def param_lists(self) -> Sequence['outputs.RuleTargetParamList']:
        """
        The parameters that are configured for the event target. See `param_list` below.
        """
        return pulumi.get(self, "param_lists")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> str:
        """
        The ID of the custom event target.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the event target. Valid values: `acs.alikafka`, `acs.api.destination`, `acs.arms.loki`, `acs.datahub`, `acs.dingtalk`, `acs.eventbridge`, `acs.eventbridge.olap`, `acs.eventbus.SLSCloudLens`, `acs.fc.function`, `acs.fnf`, `acs.k8s`, `acs.mail`, `acs.mns.queue`, `acs.mns.topic`, `acs.openapi`, `acs.rabbitmq`, `acs.rds.mysql`, `acs.rocketmq`, `acs.sae`, `acs.sls`, `acs.sms`, `http`,`https` and `mysql`.
        **NOTE:** From version 1.208.1, `type` can be set to `acs.alikafka`, `acs.api.destination`, `acs.arms.loki`, `acs.datahub`, `acs.eventbridge.olap`, `acs.eventbus.SLSCloudLens`, `acs.fnf`, `acs.k8s`, `acs.openapi`, `acs.rds.mysql`, `acs.sae`, `acs.sls`, `mysql`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="deadLetterQueue")
    def dead_letter_queue(self) -> Optional['outputs.RuleTargetDeadLetterQueue']:
        """
        The dead letter queue. Events that are not processed or exceed the number of retries will be written to the dead letter. Support message service MNS and message queue RocketMQ. See `dead_letter_queue` below.
        """
        return pulumi.get(self, "dead_letter_queue")

    @property
    @pulumi.getter(name="pushRetryStrategy")
    def push_retry_strategy(self) -> Optional[str]:
        """
        The retry policy that is used to push the event. Valid values:
        - `BACKOFF_RETRY`: Backoff retry. The request can be retried up to three times. The interval between two consecutive retries is a random value between 10 and 20 seconds.
        - `EXPONENTIAL_DECAY_RETRY`: Exponential decay retry. The request can be retried up to 176 times. The interval between two consecutive retries exponentially increases to 512 seconds, and the total retry time is one day. The specific retry intervals are 1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 512, ..., and 512 seconds, including a maximum of one hundred and sixty-seven 512 seconds in total.
        """
        return pulumi.get(self, "push_retry_strategy")


@pulumi.output_type
class RuleTargetDeadLetterQueue(dict):
    def __init__(__self__, *,
                 arn: Optional[str] = None):
        """
        :param str arn: The Alibaba Cloud Resource Name (ARN) of the dead letter queue. Events that are not processed or whose maximum retries are exceeded are written to the dead-letter queue. The ARN feature is supported by the following queue types: MNS and Message Queue for Apache RocketMQ.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)

    @property
    @pulumi.getter
    def arn(self) -> Optional[str]:
        """
        The Alibaba Cloud Resource Name (ARN) of the dead letter queue. Events that are not processed or whose maximum retries are exceeded are written to the dead-letter queue. The ARN feature is supported by the following queue types: MNS and Message Queue for Apache RocketMQ.
        """
        return pulumi.get(self, "arn")


@pulumi.output_type
class RuleTargetParamList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceKey":
            suggest = "resource_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RuleTargetParamList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RuleTargetParamList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RuleTargetParamList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 form: str,
                 resource_key: str,
                 template: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str form: The format of the event target parameter. Valid values: `ORIGINAL`, `TEMPLATE`, `JSONPATH`, `CONSTANT`.
        :param str resource_key: The resource parameter of the event target. For more information, see [How to use it](https://www.alibabacloud.com/help/en/eventbridge/latest/event-target-parameters)
        :param str template: The template of the event target parameter.
        :param str value: The value of the event target parameter.
               
               > **NOTE:** There exists a potential diff error that the backend service will return a default param as following:
               
               ```
               param_list {
               resource_key = "IsBase64Encode"
               form         = "CONSTANT"
               value        = "false"
               template     = ""
               }
               ```
               
               In order to fix the diff, from version 1.160.0, this resource has removed the param which `resource_key = "IsBase64Encode"` and `value = "false"`.
               If you want to set `resource_key = "IsBase64Encode"`, please avoid to set `value = "false"`.
        """
        pulumi.set(__self__, "form", form)
        pulumi.set(__self__, "resource_key", resource_key)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def form(self) -> str:
        """
        The format of the event target parameter. Valid values: `ORIGINAL`, `TEMPLATE`, `JSONPATH`, `CONSTANT`.
        """
        return pulumi.get(self, "form")

    @property
    @pulumi.getter(name="resourceKey")
    def resource_key(self) -> str:
        """
        The resource parameter of the event target. For more information, see [How to use it](https://www.alibabacloud.com/help/en/eventbridge/latest/event-target-parameters)
        """
        return pulumi.get(self, "resource_key")

    @property
    @pulumi.getter
    def template(self) -> Optional[str]:
        """
        The template of the event target parameter.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The value of the event target parameter.

        > **NOTE:** There exists a potential diff error that the backend service will return a default param as following:

        ```
        param_list {
        resource_key = "IsBase64Encode"
        form         = "CONSTANT"
        value        = "false"
        template     = ""
        }
        ```

        In order to fix the diff, from version 1.160.0, this resource has removed the param which `resource_key = "IsBase64Encode"` and `value = "false"`.
        If you want to set `resource_key = "IsBase64Encode"`, please avoid to set `value = "false"`.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetEventBusesBusResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 description: str,
                 event_bus_name: str,
                 id: str):
        """
        :param str create_time: The time of this bus was created.
        :param str description: The description of event bus.
        :param str event_bus_name: The name of event bus.
        :param str id: The ID of the Event Bus. Its value is same as Queue Name.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "event_bus_name", event_bus_name)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The time of this bus was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of event bus.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eventBusName")
    def event_bus_name(self) -> str:
        """
        The name of event bus.
        """
        return pulumi.get(self, "event_bus_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Event Bus. Its value is same as Queue Name.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class GetEventSourcesSourceResult(dict):
    def __init__(__self__, *,
                 description: str,
                 event_source_name: str,
                 external_source_config: Mapping[str, str],
                 external_source_type: str,
                 id: str,
                 linked_external_source: bool,
                 type: str):
        """
        :param str description: The detail describe of event source.
        :param str event_source_name: The code name of event source.
        :param Mapping[str, str] external_source_config: The config of external data source.
        :param str external_source_type: The type of external data source.
        :param str id: The ID of the Event Source.
        :param bool linked_external_source: Whether to connect to an external data source.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "event_source_name", event_source_name)
        pulumi.set(__self__, "external_source_config", external_source_config)
        pulumi.set(__self__, "external_source_type", external_source_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "linked_external_source", linked_external_source)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The detail describe of event source.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eventSourceName")
    def event_source_name(self) -> str:
        """
        The code name of event source.
        """
        return pulumi.get(self, "event_source_name")

    @property
    @pulumi.getter(name="externalSourceConfig")
    def external_source_config(self) -> Mapping[str, str]:
        """
        The config of external data source.
        """
        return pulumi.get(self, "external_source_config")

    @property
    @pulumi.getter(name="externalSourceType")
    def external_source_type(self) -> str:
        """
        The type of external data source.
        """
        return pulumi.get(self, "external_source_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Event Source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="linkedExternalSource")
    def linked_external_source(self) -> bool:
        """
        Whether to connect to an external data source.
        """
        return pulumi.get(self, "linked_external_source")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetRulesRuleResult(dict):
    def __init__(__self__, *,
                 description: str,
                 event_bus_name: str,
                 filter_pattern: str,
                 id: str,
                 rule_name: str,
                 status: str,
                 targets: Sequence['outputs.GetRulesRuleTargetResult']):
        """
        :param str description: The description of rule.
        :param str event_bus_name: The name of event bus.
        :param str filter_pattern: The pattern to match interested events.
        :param str id: The ID of the Rule.
        :param str rule_name: The name of rule.
        :param str status: Rule status, either Enable or Disable.
        :param Sequence['GetRulesRuleTargetArgs'] targets: The target for rule.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "event_bus_name", event_bus_name)
        pulumi.set(__self__, "filter_pattern", filter_pattern)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "targets", targets)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of rule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eventBusName")
    def event_bus_name(self) -> str:
        """
        The name of event bus.
        """
        return pulumi.get(self, "event_bus_name")

    @property
    @pulumi.getter(name="filterPattern")
    def filter_pattern(self) -> str:
        """
        The pattern to match interested events.
        """
        return pulumi.get(self, "filter_pattern")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Rule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> str:
        """
        The name of rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Rule status, either Enable or Disable.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def targets(self) -> Sequence['outputs.GetRulesRuleTargetResult']:
        """
        The target for rule.
        """
        return pulumi.get(self, "targets")


@pulumi.output_type
class GetRulesRuleTargetResult(dict):
    def __init__(__self__, *,
                 endpoint: str,
                 target_id: str,
                 type: str):
        """
        :param str endpoint: The endpoint.
        :param str target_id: The id of target.
        :param str type: The type of target.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "target_id", target_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def endpoint(self) -> str:
        """
        The endpoint.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> str:
        """
        The id of target.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of target.
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetStackInstancesResult',
    'AwaitableGetStackInstancesResult',
    'get_stack_instances',
    'get_stack_instances_output',
]

@pulumi.output_type
class GetStackInstancesResult:
    """
    A collection of values returned by getStackInstances.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, instances=None, output_file=None, stack_group_name=None, stack_instance_account_id=None, stack_instance_region_id=None, status=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if stack_group_name and not isinstance(stack_group_name, str):
            raise TypeError("Expected argument 'stack_group_name' to be a str")
        pulumi.set(__self__, "stack_group_name", stack_group_name)
        if stack_instance_account_id and not isinstance(stack_instance_account_id, str):
            raise TypeError("Expected argument 'stack_instance_account_id' to be a str")
        pulumi.set(__self__, "stack_instance_account_id", stack_instance_account_id)
        if stack_instance_region_id and not isinstance(stack_instance_region_id, str):
            raise TypeError("Expected argument 'stack_instance_region_id' to be a str")
        pulumi.set(__self__, "stack_instance_region_id", stack_instance_region_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetStackInstancesInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="stackGroupName")
    def stack_group_name(self) -> str:
        return pulumi.get(self, "stack_group_name")

    @property
    @pulumi.getter(name="stackInstanceAccountId")
    def stack_instance_account_id(self) -> Optional[str]:
        return pulumi.get(self, "stack_instance_account_id")

    @property
    @pulumi.getter(name="stackInstanceRegionId")
    def stack_instance_region_id(self) -> Optional[str]:
        return pulumi.get(self, "stack_instance_region_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetStackInstancesResult(GetStackInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStackInstancesResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            instances=self.instances,
            output_file=self.output_file,
            stack_group_name=self.stack_group_name,
            stack_instance_account_id=self.stack_instance_account_id,
            stack_instance_region_id=self.stack_instance_region_id,
            status=self.status)


def get_stack_instances(enable_details: Optional[bool] = None,
                        ids: Optional[Sequence[str]] = None,
                        output_file: Optional[str] = None,
                        stack_group_name: Optional[str] = None,
                        stack_instance_account_id: Optional[str] = None,
                        stack_instance_region_id: Optional[str] = None,
                        status: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStackInstancesResult:
    """
    This data source provides the Ros Stack Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.145.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ],
        enable_details=True)
    pulumi.export("rosStackInstanceId1", ids.instances[0].id)
    status = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        status="CURRENT",
        enable_details=True)
    pulumi.export("rosStackInstanceId2", status.instances[0].id)
    region_id = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        stack_instance_region_id="example_value",
        enable_details=True)
    pulumi.export("rosStackInstanceId3", region_id.instances[0].id)
    account_id = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        stack_instance_account_id="example_value",
        enable_details=True)
    pulumi.export("rosStackInstanceId4", account_id.instances[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Stack Instance IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str stack_group_name: The name of the stack group.
    :param str stack_instance_account_id: The account to which the stack instance belongs.
    :param str stack_instance_region_id: The region of the stack instance.
    :param str status: The status of the stack instance. Valid values: `CURRENT` or `OUTDATED`. 
           * `CURRENT`: The stack corresponding to the stack instance is up to date with the stack group.
           * `OUTDATED`: The stack corresponding to the stack instance is not up to date with the stack group. The `OUTDATED` state has the following possible causes:
           * When the CreateStackInstances operation is called to create stack instances, the corresponding stacks fail to be created.
           * When the UpdateStackInstances or UpdateStackGroup operation is called to update stack instances, the corresponding stacks fail to be updated, or only some of the stack instances are updated.
           * The create or update operation is not complete.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['stackGroupName'] = stack_group_name
    __args__['stackInstanceAccountId'] = stack_instance_account_id
    __args__['stackInstanceRegionId'] = stack_instance_region_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ros/getStackInstances:getStackInstances', __args__, opts=opts, typ=GetStackInstancesResult).value

    return AwaitableGetStackInstancesResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instances=pulumi.get(__ret__, 'instances'),
        output_file=pulumi.get(__ret__, 'output_file'),
        stack_group_name=pulumi.get(__ret__, 'stack_group_name'),
        stack_instance_account_id=pulumi.get(__ret__, 'stack_instance_account_id'),
        stack_instance_region_id=pulumi.get(__ret__, 'stack_instance_region_id'),
        status=pulumi.get(__ret__, 'status'))
def get_stack_instances_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               stack_group_name: Optional[pulumi.Input[str]] = None,
                               stack_instance_account_id: Optional[pulumi.Input[Optional[str]]] = None,
                               stack_instance_region_id: Optional[pulumi.Input[Optional[str]]] = None,
                               status: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStackInstancesResult]:
    """
    This data source provides the Ros Stack Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.145.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ],
        enable_details=True)
    pulumi.export("rosStackInstanceId1", ids.instances[0].id)
    status = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        status="CURRENT",
        enable_details=True)
    pulumi.export("rosStackInstanceId2", status.instances[0].id)
    region_id = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        stack_instance_region_id="example_value",
        enable_details=True)
    pulumi.export("rosStackInstanceId3", region_id.instances[0].id)
    account_id = alicloud.ros.get_stack_instances(stack_group_name="example_value",
        stack_instance_account_id="example_value",
        enable_details=True)
    pulumi.export("rosStackInstanceId4", account_id.instances[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Stack Instance IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str stack_group_name: The name of the stack group.
    :param str stack_instance_account_id: The account to which the stack instance belongs.
    :param str stack_instance_region_id: The region of the stack instance.
    :param str status: The status of the stack instance. Valid values: `CURRENT` or `OUTDATED`. 
           * `CURRENT`: The stack corresponding to the stack instance is up to date with the stack group.
           * `OUTDATED`: The stack corresponding to the stack instance is not up to date with the stack group. The `OUTDATED` state has the following possible causes:
           * When the CreateStackInstances operation is called to create stack instances, the corresponding stacks fail to be created.
           * When the UpdateStackInstances or UpdateStackGroup operation is called to update stack instances, the corresponding stacks fail to be updated, or only some of the stack instances are updated.
           * The create or update operation is not complete.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['stackGroupName'] = stack_group_name
    __args__['stackInstanceAccountId'] = stack_instance_account_id
    __args__['stackInstanceRegionId'] = stack_instance_region_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ros/getStackInstances:getStackInstances', __args__, opts=opts, typ=GetStackInstancesResult)
    return __ret__.apply(lambda __response__: GetStackInstancesResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instances=pulumi.get(__response__, 'instances'),
        output_file=pulumi.get(__response__, 'output_file'),
        stack_group_name=pulumi.get(__response__, 'stack_group_name'),
        stack_instance_account_id=pulumi.get(__response__, 'stack_instance_account_id'),
        stack_instance_region_id=pulumi.get(__response__, 'stack_instance_region_id'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceAclAttachmentArgs', 'InstanceAclAttachment']

@pulumi.input_type
class InstanceAclAttachmentArgs:
    def __init__(__self__, *,
                 acl_id: pulumi.Input[str],
                 acl_type: pulumi.Input[str],
                 instance_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a InstanceAclAttachment resource.
        :param pulumi.Input[str] acl_id: The ID of the ACL to attach.
        :param pulumi.Input[str] acl_type: The type of the ACL. Valid values: `white`, `black`.
        :param pulumi.Input[str] instance_id: The ID of the API Gateway instance that the ACL will be attached to.
        """
        pulumi.set(__self__, "acl_id", acl_id)
        pulumi.set(__self__, "acl_type", acl_type)
        pulumi.set(__self__, "instance_id", instance_id)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> pulumi.Input[str]:
        """
        The ID of the ACL to attach.
        """
        return pulumi.get(self, "acl_id")

    @acl_id.setter
    def acl_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "acl_id", value)

    @property
    @pulumi.getter(name="aclType")
    def acl_type(self) -> pulumi.Input[str]:
        """
        The type of the ACL. Valid values: `white`, `black`.
        """
        return pulumi.get(self, "acl_type")

    @acl_type.setter
    def acl_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "acl_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the API Gateway instance that the ACL will be attached to.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)


@pulumi.input_type
class _InstanceAclAttachmentState:
    def __init__(__self__, *,
                 acl_id: Optional[pulumi.Input[str]] = None,
                 acl_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering InstanceAclAttachment resources.
        :param pulumi.Input[str] acl_id: The ID of the ACL to attach.
        :param pulumi.Input[str] acl_type: The type of the ACL. Valid values: `white`, `black`.
        :param pulumi.Input[str] instance_id: The ID of the API Gateway instance that the ACL will be attached to.
        """
        if acl_id is not None:
            pulumi.set(__self__, "acl_id", acl_id)
        if acl_type is not None:
            pulumi.set(__self__, "acl_type", acl_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the ACL to attach.
        """
        return pulumi.get(self, "acl_id")

    @acl_id.setter
    def acl_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "acl_id", value)

    @property
    @pulumi.getter(name="aclType")
    def acl_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the ACL. Valid values: `white`, `black`.
        """
        return pulumi.get(self, "acl_type")

    @acl_type.setter
    def acl_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "acl_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the API Gateway instance that the ACL will be attached to.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)


class InstanceAclAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_id: Optional[pulumi.Input[str]] = None,
                 acl_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides an Instance ACL attachment resource for attaching an ACL to a specific API Gateway instance.

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.apigateway.Instance("default",
            instance_name=name,
            instance_spec="api.s1.small",
            https_policy="HTTPS2_TLS1_0",
            zone_id="cn-hangzhou-MAZ6",
            payment_type="PayAsYouGo",
            instance_type="normal")
        default_access_control_list = alicloud.apigateway.AccessControlList("default",
            access_control_list_name=name,
            address_ip_version="ipv4")
        default_acl_entry_attachment = alicloud.apigateway.AclEntryAttachment("default",
            acl_id=default_access_control_list.id,
            entry="128.0.0.1/32",
            comment="test comment")
        default_instance_acl_attachment = alicloud.apigateway.InstanceAclAttachment("default",
            instance_id=default.id,
            acl_id=default_access_control_list.id,
            acl_type="white")
        ```

        ## Import

        Api Gateway Instance Acl Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/instanceAclAttachment:InstanceAclAttachment example <instance_id>:<acl_id>:<acl_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] acl_id: The ID of the ACL to attach.
        :param pulumi.Input[str] acl_type: The type of the ACL. Valid values: `white`, `black`.
        :param pulumi.Input[str] instance_id: The ID of the API Gateway instance that the ACL will be attached to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceAclAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an Instance ACL attachment resource for attaching an ACL to a specific API Gateway instance.

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.apigateway.Instance("default",
            instance_name=name,
            instance_spec="api.s1.small",
            https_policy="HTTPS2_TLS1_0",
            zone_id="cn-hangzhou-MAZ6",
            payment_type="PayAsYouGo",
            instance_type="normal")
        default_access_control_list = alicloud.apigateway.AccessControlList("default",
            access_control_list_name=name,
            address_ip_version="ipv4")
        default_acl_entry_attachment = alicloud.apigateway.AclEntryAttachment("default",
            acl_id=default_access_control_list.id,
            entry="128.0.0.1/32",
            comment="test comment")
        default_instance_acl_attachment = alicloud.apigateway.InstanceAclAttachment("default",
            instance_id=default.id,
            acl_id=default_access_control_list.id,
            acl_type="white")
        ```

        ## Import

        Api Gateway Instance Acl Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/instanceAclAttachment:InstanceAclAttachment example <instance_id>:<acl_id>:<acl_type>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceAclAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceAclAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_id: Optional[pulumi.Input[str]] = None,
                 acl_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceAclAttachmentArgs.__new__(InstanceAclAttachmentArgs)

            if acl_id is None and not opts.urn:
                raise TypeError("Missing required property 'acl_id'")
            __props__.__dict__["acl_id"] = acl_id
            if acl_type is None and not opts.urn:
                raise TypeError("Missing required property 'acl_type'")
            __props__.__dict__["acl_type"] = acl_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
        super(InstanceAclAttachment, __self__).__init__(
            'alicloud:apigateway/instanceAclAttachment:InstanceAclAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_id: Optional[pulumi.Input[str]] = None,
            acl_type: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None) -> 'InstanceAclAttachment':
        """
        Get an existing InstanceAclAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] acl_id: The ID of the ACL to attach.
        :param pulumi.Input[str] acl_type: The type of the ACL. Valid values: `white`, `black`.
        :param pulumi.Input[str] instance_id: The ID of the API Gateway instance that the ACL will be attached to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceAclAttachmentState.__new__(_InstanceAclAttachmentState)

        __props__.__dict__["acl_id"] = acl_id
        __props__.__dict__["acl_type"] = acl_type
        __props__.__dict__["instance_id"] = instance_id
        return InstanceAclAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> pulumi.Output[str]:
        """
        The ID of the ACL to attach.
        """
        return pulumi.get(self, "acl_id")

    @property
    @pulumi.getter(name="aclType")
    def acl_type(self) -> pulumi.Output[str]:
        """
        The type of the ACL. Valid values: `white`, `black`.
        """
        return pulumi.get(self, "acl_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the API Gateway instance that the ACL will be attached to.
        """
        return pulumi.get(self, "instance_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetModelsResult',
    'AwaitableGetModelsResult',
    'get_models',
    'get_models_output',
]

@pulumi.output_type
class GetModelsResult:
    """
    A collection of values returned by getModels.
    """
    def __init__(__self__, group_id=None, id=None, ids=None, model_name=None, models=None, name_regex=None, names=None, output_file=None, page_number=None, page_size=None):
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if model_name and not isinstance(model_name, str):
            raise TypeError("Expected argument 'model_name' to be a str")
        pulumi.set(__self__, "model_name", model_name)
        if models and not isinstance(models, list):
            raise TypeError("Expected argument 'models' to be a list")
        pulumi.set(__self__, "models", models)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        """
        The group of the model belongs to.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> Optional[str]:
        """
        The name of the Model.
        """
        return pulumi.get(self, "model_name")

    @property
    @pulumi.getter
    def models(self) -> Sequence['outputs.GetModelsModelResult']:
        """
        A list of Api Gateway Models. Each element contains the following attributes:
        """
        return pulumi.get(self, "models")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Model names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")


class AwaitableGetModelsResult(GetModelsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetModelsResult(
            group_id=self.group_id,
            id=self.id,
            ids=self.ids,
            model_name=self.model_name,
            models=self.models,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size)


def get_models(group_id: Optional[str] = None,
               ids: Optional[Sequence[str]] = None,
               model_name: Optional[str] = None,
               name_regex: Optional[str] = None,
               output_file: Optional[str] = None,
               page_number: Optional[int] = None,
               page_size: Optional[int] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetModelsResult:
    """
    This data source provides the Api Gateway Models of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.187.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.apigateway.get_models(ids=["example_id"],
        group_id="example_group_id")
    pulumi.export("apiGatewayModelId1", ids.models[0].id)
    group_id = alicloud.apigateway.get_models(group_id="example_group_id")
    pulumi.export("apiGatewayModelId2", group_id.models[0].id)
    ```


    :param str group_id: The ID of the api group.
    :param Sequence[str] ids: A list of Model IDs.
    :param str model_name: The name of the Model.
    :param str name_regex: A regex string to filter results by Model name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['groupId'] = group_id
    __args__['ids'] = ids
    __args__['modelName'] = model_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:apigateway/getModels:getModels', __args__, opts=opts, typ=GetModelsResult).value

    return AwaitableGetModelsResult(
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        model_name=pulumi.get(__ret__, 'model_name'),
        models=pulumi.get(__ret__, 'models'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'))
def get_models_output(group_id: Optional[pulumi.Input[str]] = None,
                      ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                      model_name: Optional[pulumi.Input[Optional[str]]] = None,
                      name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                      output_file: Optional[pulumi.Input[Optional[str]]] = None,
                      page_number: Optional[pulumi.Input[Optional[int]]] = None,
                      page_size: Optional[pulumi.Input[Optional[int]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetModelsResult]:
    """
    This data source provides the Api Gateway Models of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.187.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.apigateway.get_models(ids=["example_id"],
        group_id="example_group_id")
    pulumi.export("apiGatewayModelId1", ids.models[0].id)
    group_id = alicloud.apigateway.get_models(group_id="example_group_id")
    pulumi.export("apiGatewayModelId2", group_id.models[0].id)
    ```


    :param str group_id: The ID of the api group.
    :param Sequence[str] ids: A list of Model IDs.
    :param str model_name: The name of the Model.
    :param str name_regex: A regex string to filter results by Model name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['groupId'] = group_id
    __args__['ids'] = ids
    __args__['modelName'] = model_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:apigateway/getModels:getModels', __args__, opts=opts, typ=GetModelsResult)
    return __ret__.apply(lambda __response__: GetModelsResult(
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        model_name=pulumi.get(__response__, 'model_name'),
        models=pulumi.get(__response__, 'models'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRoutersResult',
    'AwaitableGetTransitRoutersResult',
    'get_transit_routers',
    'get_transit_routers_output',
]

@pulumi.output_type
class GetTransitRoutersResult:
    """
    A collection of values returned by getTransitRouters.
    """
    def __init__(__self__, cen_id=None, id=None, ids=None, name_regex=None, names=None, output_file=None, status=None, transit_router_id=None, transit_router_ids=None, transit_routers=None):
        if cen_id and not isinstance(cen_id, str):
            raise TypeError("Expected argument 'cen_id' to be a str")
        pulumi.set(__self__, "cen_id", cen_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_ids and not isinstance(transit_router_ids, list):
            raise TypeError("Expected argument 'transit_router_ids' to be a list")
        pulumi.set(__self__, "transit_router_ids", transit_router_ids)
        if transit_routers and not isinstance(transit_routers, list):
            raise TypeError("Expected argument 'transit_routers' to be a list")
        pulumi.set(__self__, "transit_routers", transit_routers)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> str:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of  CEN Transit Routers names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the transit router attachment.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[str]:
        """
        The ID of the transit router.
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterIds")
    def transit_router_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "transit_router_ids")

    @property
    @pulumi.getter(name="transitRouters")
    def transit_routers(self) -> Sequence['outputs.GetTransitRoutersTransitRouterResult']:
        """
        A list of CEN Transit Routers. Each element contains the following attributes:
        """
        return pulumi.get(self, "transit_routers")


class AwaitableGetTransitRoutersResult(GetTransitRoutersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRoutersResult(
            cen_id=self.cen_id,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status,
            transit_router_id=self.transit_router_id,
            transit_router_ids=self.transit_router_ids,
            transit_routers=self.transit_routers)


def get_transit_routers(cen_id: Optional[str] = None,
                        ids: Optional[Sequence[str]] = None,
                        name_regex: Optional[str] = None,
                        output_file: Optional[str] = None,
                        status: Optional[str] = None,
                        transit_router_id: Optional[str] = None,
                        transit_router_ids: Optional[Sequence[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRoutersResult:
    """
    This data source provides CEN Transit Routers available to the user.[What is Cen Transit Routers](https://help.aliyun.com/document_detail/261219.html)

    > **NOTE:** Available in 1.126.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_transit_routers(cen_id="cen-id1")
    pulumi.export("firstTransitRoutersType", default.transit_routers[0].type)
    ```


    :param str cen_id: The ID of the CEN instance.
    :param Sequence[str] ids: A list of resource id. The element value is same as <cen_id>:<transit_router_id>`.
    :param str name_regex: A regex string to filter CEN Transit Routers by name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the resource. Valid values `Active`, `Creating`, `Deleting` and `Updating`.
    :param str transit_router_id: The ID of the transit router.
    :param Sequence[str] transit_router_ids: A list of ID of the transit router.
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['transitRouterId'] = transit_router_id
    __args__['transitRouterIds'] = transit_router_ids
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getTransitRouters:getTransitRouters', __args__, opts=opts, typ=GetTransitRoutersResult).value

    return AwaitableGetTransitRoutersResult(
        cen_id=pulumi.get(__ret__, 'cen_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'),
        transit_router_ids=pulumi.get(__ret__, 'transit_router_ids'),
        transit_routers=pulumi.get(__ret__, 'transit_routers'))
def get_transit_routers_output(cen_id: Optional[pulumi.Input[str]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               status: Optional[pulumi.Input[Optional[str]]] = None,
                               transit_router_id: Optional[pulumi.Input[Optional[str]]] = None,
                               transit_router_ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTransitRoutersResult]:
    """
    This data source provides CEN Transit Routers available to the user.[What is Cen Transit Routers](https://help.aliyun.com/document_detail/261219.html)

    > **NOTE:** Available in 1.126.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.cen.get_transit_routers(cen_id="cen-id1")
    pulumi.export("firstTransitRoutersType", default.transit_routers[0].type)
    ```


    :param str cen_id: The ID of the CEN instance.
    :param Sequence[str] ids: A list of resource id. The element value is same as <cen_id>:<transit_router_id>`.
    :param str name_regex: A regex string to filter CEN Transit Routers by name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the resource. Valid values `Active`, `Creating`, `Deleting` and `Updating`.
    :param str transit_router_id: The ID of the transit router.
    :param Sequence[str] transit_router_ids: A list of ID of the transit router.
    """
    __args__ = dict()
    __args__['cenId'] = cen_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['transitRouterId'] = transit_router_id
    __args__['transitRouterIds'] = transit_router_ids
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getTransitRouters:getTransitRouters', __args__, opts=opts, typ=GetTransitRoutersResult)
    return __ret__.apply(lambda __response__: GetTransitRoutersResult(
        cen_id=pulumi.get(__response__, 'cen_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id'),
        transit_router_ids=pulumi.get(__response__, 'transit_router_ids'),
        transit_routers=pulumi.get(__response__, 'transit_routers')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['StreamingJobArgs', 'StreamingJob']

@pulumi.input_type
class StreamingJobArgs:
    def __init__(__self__, *,
                 data_source_id: pulumi.Input[str],
                 db_instance_id: pulumi.Input[str],
                 job_name: pulumi.Input[str],
                 account: Optional[pulumi.Input[str]] = None,
                 consistency: Optional[pulumi.Input[str]] = None,
                 dest_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dest_database: Optional[pulumi.Input[str]] = None,
                 dest_schema: Optional[pulumi.Input[str]] = None,
                 dest_table: Optional[pulumi.Input[str]] = None,
                 error_limit_count: Optional[pulumi.Input[int]] = None,
                 fallback_offset: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 job_config: Optional[pulumi.Input[str]] = None,
                 job_description: Optional[pulumi.Input[str]] = None,
                 match_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 src_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 try_run: Optional[pulumi.Input[bool]] = None,
                 update_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 write_mode: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a StreamingJob resource.
        :param pulumi.Input[str] data_source_id: The data source ID.
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[str] job_name: The name of the job.
        :param pulumi.Input[str] account: The name of the database account.
        :param pulumi.Input[str] consistency: The delivery guarantee setting.
               
               Valid values:
               
               - ATLEAST
               - EXACTLY
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dest_columns: Target Field
        :param pulumi.Input[str] dest_database: The name of the destination database.
        :param pulumi.Input[str] dest_schema: Target Schema
        :param pulumi.Input[str] dest_table: The name of the destination table.
        :param pulumi.Input[int] error_limit_count: The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        :param pulumi.Input[str] fallback_offset: Automatic offset reset
        :param pulumi.Input[str] group_name: Group Name
        :param pulumi.Input[str] job_config: The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        :param pulumi.Input[str] job_description: The description of the job.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] match_columns: Match Field
        :param pulumi.Input[str] mode: The configuration mode. Valid values:
               
               1.  basic: In basic mode, you must configure the configuration parameters.
               
               2.  professional: In professional mode, you can submit a YAML configuration file.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_columns: Source Field
        :param pulumi.Input[bool] try_run: Specifies whether to test the real-time job. Valid values:
               
               - true
               - false
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] update_columns: Update Field
        :param pulumi.Input[str] write_mode: The write mode.
               
               Valid values:
               
               - insert
               - update
               - merge
        """
        pulumi.set(__self__, "data_source_id", data_source_id)
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        pulumi.set(__self__, "job_name", job_name)
        if account is not None:
            pulumi.set(__self__, "account", account)
        if consistency is not None:
            pulumi.set(__self__, "consistency", consistency)
        if dest_columns is not None:
            pulumi.set(__self__, "dest_columns", dest_columns)
        if dest_database is not None:
            pulumi.set(__self__, "dest_database", dest_database)
        if dest_schema is not None:
            pulumi.set(__self__, "dest_schema", dest_schema)
        if dest_table is not None:
            pulumi.set(__self__, "dest_table", dest_table)
        if error_limit_count is not None:
            pulumi.set(__self__, "error_limit_count", error_limit_count)
        if fallback_offset is not None:
            pulumi.set(__self__, "fallback_offset", fallback_offset)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if job_config is not None:
            pulumi.set(__self__, "job_config", job_config)
        if job_description is not None:
            pulumi.set(__self__, "job_description", job_description)
        if match_columns is not None:
            pulumi.set(__self__, "match_columns", match_columns)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if src_columns is not None:
            pulumi.set(__self__, "src_columns", src_columns)
        if try_run is not None:
            pulumi.set(__self__, "try_run", try_run)
        if update_columns is not None:
            pulumi.set(__self__, "update_columns", update_columns)
        if write_mode is not None:
            pulumi.set(__self__, "write_mode", write_mode)

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> pulumi.Input[str]:
        """
        The data source ID.
        """
        return pulumi.get(self, "data_source_id")

    @data_source_id.setter
    def data_source_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "data_source_id", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[str]:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Input[str]:
        """
        The name of the job.
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter
    def account(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the database account.
        """
        return pulumi.get(self, "account")

    @account.setter
    def account(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account", value)

    @property
    @pulumi.getter
    def consistency(self) -> Optional[pulumi.Input[str]]:
        """
        The delivery guarantee setting.

        Valid values:

        - ATLEAST
        - EXACTLY
        """
        return pulumi.get(self, "consistency")

    @consistency.setter
    def consistency(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consistency", value)

    @property
    @pulumi.getter(name="destColumns")
    def dest_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Target Field
        """
        return pulumi.get(self, "dest_columns")

    @dest_columns.setter
    def dest_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dest_columns", value)

    @property
    @pulumi.getter(name="destDatabase")
    def dest_database(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the destination database.
        """
        return pulumi.get(self, "dest_database")

    @dest_database.setter
    def dest_database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_database", value)

    @property
    @pulumi.getter(name="destSchema")
    def dest_schema(self) -> Optional[pulumi.Input[str]]:
        """
        Target Schema
        """
        return pulumi.get(self, "dest_schema")

    @dest_schema.setter
    def dest_schema(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_schema", value)

    @property
    @pulumi.getter(name="destTable")
    def dest_table(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the destination table.
        """
        return pulumi.get(self, "dest_table")

    @dest_table.setter
    def dest_table(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_table", value)

    @property
    @pulumi.getter(name="errorLimitCount")
    def error_limit_count(self) -> Optional[pulumi.Input[int]]:
        """
        The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        """
        return pulumi.get(self, "error_limit_count")

    @error_limit_count.setter
    def error_limit_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "error_limit_count", value)

    @property
    @pulumi.getter(name="fallbackOffset")
    def fallback_offset(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic offset reset
        """
        return pulumi.get(self, "fallback_offset")

    @fallback_offset.setter
    def fallback_offset(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fallback_offset", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Group Name
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="jobConfig")
    def job_config(self) -> Optional[pulumi.Input[str]]:
        """
        The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        """
        return pulumi.get(self, "job_config")

    @job_config.setter
    def job_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_config", value)

    @property
    @pulumi.getter(name="jobDescription")
    def job_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the job.
        """
        return pulumi.get(self, "job_description")

    @job_description.setter
    def job_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_description", value)

    @property
    @pulumi.getter(name="matchColumns")
    def match_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Match Field
        """
        return pulumi.get(self, "match_columns")

    @match_columns.setter
    def match_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "match_columns", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration mode. Valid values:

        1.  basic: In basic mode, you must configure the configuration parameters.

        2.  professional: In professional mode, you can submit a YAML configuration file.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the database account.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="srcColumns")
    def src_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Source Field
        """
        return pulumi.get(self, "src_columns")

    @src_columns.setter
    def src_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "src_columns", value)

    @property
    @pulumi.getter(name="tryRun")
    def try_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to test the real-time job. Valid values:

        - true
        - false

        Default value: false.
        """
        return pulumi.get(self, "try_run")

    @try_run.setter
    def try_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "try_run", value)

    @property
    @pulumi.getter(name="updateColumns")
    def update_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Update Field
        """
        return pulumi.get(self, "update_columns")

    @update_columns.setter
    def update_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "update_columns", value)

    @property
    @pulumi.getter(name="writeMode")
    def write_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The write mode.

        Valid values:

        - insert
        - update
        - merge
        """
        return pulumi.get(self, "write_mode")

    @write_mode.setter
    def write_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "write_mode", value)


@pulumi.input_type
class _StreamingJobState:
    def __init__(__self__, *,
                 account: Optional[pulumi.Input[str]] = None,
                 consistency: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 data_source_id: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 dest_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dest_database: Optional[pulumi.Input[str]] = None,
                 dest_schema: Optional[pulumi.Input[str]] = None,
                 dest_table: Optional[pulumi.Input[str]] = None,
                 error_limit_count: Optional[pulumi.Input[int]] = None,
                 fallback_offset: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 job_config: Optional[pulumi.Input[str]] = None,
                 job_description: Optional[pulumi.Input[str]] = None,
                 job_id: Optional[pulumi.Input[str]] = None,
                 job_name: Optional[pulumi.Input[str]] = None,
                 match_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 src_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 try_run: Optional[pulumi.Input[bool]] = None,
                 update_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 write_mode: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering StreamingJob resources.
        :param pulumi.Input[str] account: The name of the database account.
        :param pulumi.Input[str] consistency: The delivery guarantee setting.
               
               Valid values:
               
               - ATLEAST
               - EXACTLY
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] data_source_id: The data source ID.
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dest_columns: Target Field
        :param pulumi.Input[str] dest_database: The name of the destination database.
        :param pulumi.Input[str] dest_schema: Target Schema
        :param pulumi.Input[str] dest_table: The name of the destination table.
        :param pulumi.Input[int] error_limit_count: The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        :param pulumi.Input[str] fallback_offset: Automatic offset reset
        :param pulumi.Input[str] group_name: Group Name
        :param pulumi.Input[str] job_config: The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        :param pulumi.Input[str] job_description: The description of the job.
        :param pulumi.Input[str] job_id: The job ID.
        :param pulumi.Input[str] job_name: The name of the job.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] match_columns: Match Field
        :param pulumi.Input[str] mode: The configuration mode. Valid values:
               
               1.  basic: In basic mode, you must configure the configuration parameters.
               
               2.  professional: In professional mode, you can submit a YAML configuration file.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_columns: Source Field
        :param pulumi.Input[str] status: Service status, value:
        :param pulumi.Input[bool] try_run: Specifies whether to test the real-time job. Valid values:
               
               - true
               - false
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] update_columns: Update Field
        :param pulumi.Input[str] write_mode: The write mode.
               
               Valid values:
               
               - insert
               - update
               - merge
        """
        if account is not None:
            pulumi.set(__self__, "account", account)
        if consistency is not None:
            pulumi.set(__self__, "consistency", consistency)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data_source_id is not None:
            pulumi.set(__self__, "data_source_id", data_source_id)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if dest_columns is not None:
            pulumi.set(__self__, "dest_columns", dest_columns)
        if dest_database is not None:
            pulumi.set(__self__, "dest_database", dest_database)
        if dest_schema is not None:
            pulumi.set(__self__, "dest_schema", dest_schema)
        if dest_table is not None:
            pulumi.set(__self__, "dest_table", dest_table)
        if error_limit_count is not None:
            pulumi.set(__self__, "error_limit_count", error_limit_count)
        if fallback_offset is not None:
            pulumi.set(__self__, "fallback_offset", fallback_offset)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if job_config is not None:
            pulumi.set(__self__, "job_config", job_config)
        if job_description is not None:
            pulumi.set(__self__, "job_description", job_description)
        if job_id is not None:
            pulumi.set(__self__, "job_id", job_id)
        if job_name is not None:
            pulumi.set(__self__, "job_name", job_name)
        if match_columns is not None:
            pulumi.set(__self__, "match_columns", match_columns)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if src_columns is not None:
            pulumi.set(__self__, "src_columns", src_columns)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if try_run is not None:
            pulumi.set(__self__, "try_run", try_run)
        if update_columns is not None:
            pulumi.set(__self__, "update_columns", update_columns)
        if write_mode is not None:
            pulumi.set(__self__, "write_mode", write_mode)

    @property
    @pulumi.getter
    def account(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the database account.
        """
        return pulumi.get(self, "account")

    @account.setter
    def account(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account", value)

    @property
    @pulumi.getter
    def consistency(self) -> Optional[pulumi.Input[str]]:
        """
        The delivery guarantee setting.

        Valid values:

        - ATLEAST
        - EXACTLY
        """
        return pulumi.get(self, "consistency")

    @consistency.setter
    def consistency(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consistency", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> Optional[pulumi.Input[str]]:
        """
        The data source ID.
        """
        return pulumi.get(self, "data_source_id")

    @data_source_id.setter
    def data_source_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_id", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="destColumns")
    def dest_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Target Field
        """
        return pulumi.get(self, "dest_columns")

    @dest_columns.setter
    def dest_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dest_columns", value)

    @property
    @pulumi.getter(name="destDatabase")
    def dest_database(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the destination database.
        """
        return pulumi.get(self, "dest_database")

    @dest_database.setter
    def dest_database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_database", value)

    @property
    @pulumi.getter(name="destSchema")
    def dest_schema(self) -> Optional[pulumi.Input[str]]:
        """
        Target Schema
        """
        return pulumi.get(self, "dest_schema")

    @dest_schema.setter
    def dest_schema(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_schema", value)

    @property
    @pulumi.getter(name="destTable")
    def dest_table(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the destination table.
        """
        return pulumi.get(self, "dest_table")

    @dest_table.setter
    def dest_table(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dest_table", value)

    @property
    @pulumi.getter(name="errorLimitCount")
    def error_limit_count(self) -> Optional[pulumi.Input[int]]:
        """
        The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        """
        return pulumi.get(self, "error_limit_count")

    @error_limit_count.setter
    def error_limit_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "error_limit_count", value)

    @property
    @pulumi.getter(name="fallbackOffset")
    def fallback_offset(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic offset reset
        """
        return pulumi.get(self, "fallback_offset")

    @fallback_offset.setter
    def fallback_offset(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fallback_offset", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Group Name
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="jobConfig")
    def job_config(self) -> Optional[pulumi.Input[str]]:
        """
        The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        """
        return pulumi.get(self, "job_config")

    @job_config.setter
    def job_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_config", value)

    @property
    @pulumi.getter(name="jobDescription")
    def job_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the job.
        """
        return pulumi.get(self, "job_description")

    @job_description.setter
    def job_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_description", value)

    @property
    @pulumi.getter(name="jobId")
    def job_id(self) -> Optional[pulumi.Input[str]]:
        """
        The job ID.
        """
        return pulumi.get(self, "job_id")

    @job_id.setter
    def job_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_id", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the job.
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter(name="matchColumns")
    def match_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Match Field
        """
        return pulumi.get(self, "match_columns")

    @match_columns.setter
    def match_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "match_columns", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        The configuration mode. Valid values:

        1.  basic: In basic mode, you must configure the configuration parameters.

        2.  professional: In professional mode, you can submit a YAML configuration file.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the database account.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="srcColumns")
    def src_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Source Field
        """
        return pulumi.get(self, "src_columns")

    @src_columns.setter
    def src_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "src_columns", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Service status, value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="tryRun")
    def try_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to test the real-time job. Valid values:

        - true
        - false

        Default value: false.
        """
        return pulumi.get(self, "try_run")

    @try_run.setter
    def try_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "try_run", value)

    @property
    @pulumi.getter(name="updateColumns")
    def update_columns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Update Field
        """
        return pulumi.get(self, "update_columns")

    @update_columns.setter
    def update_columns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "update_columns", value)

    @property
    @pulumi.getter(name="writeMode")
    def write_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The write mode.

        Valid values:

        - insert
        - update
        - merge
        """
        return pulumi.get(self, "write_mode")

    @write_mode.setter
    def write_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "write_mode", value)


class StreamingJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account: Optional[pulumi.Input[str]] = None,
                 consistency: Optional[pulumi.Input[str]] = None,
                 data_source_id: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 dest_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dest_database: Optional[pulumi.Input[str]] = None,
                 dest_schema: Optional[pulumi.Input[str]] = None,
                 dest_table: Optional[pulumi.Input[str]] = None,
                 error_limit_count: Optional[pulumi.Input[int]] = None,
                 fallback_offset: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 job_config: Optional[pulumi.Input[str]] = None,
                 job_description: Optional[pulumi.Input[str]] = None,
                 job_name: Optional[pulumi.Input[str]] = None,
                 match_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 src_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 try_run: Optional[pulumi.Input[bool]] = None,
                 update_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 write_mode: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a GPDB Streaming Job resource.

        Real-time data tasks.

        For information about GPDB Streaming Job and how to use it, see [What is Streaming Job](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.231.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_t_xqb15 = alicloud.vpc.Network("defaultTXqb15", cidr_block="192.168.0.0/16")
        defaulta_s_whb_t = alicloud.vpc.Switch("defaultaSWhbT",
            vpc_id=default_t_xqb15.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        defaulth2ghc1 = alicloud.gpdb.Instance("defaulth2ghc1",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaulta_s_whb_t.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default_t_xqb15.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default2d_usz_y = alicloud.gpdb.StreamingDataService("default2dUszY",
            service_name="example",
            db_instance_id=defaulth2ghc1.id,
            service_description="example",
            service_spec="8")
        defaultc_dq_itu = alicloud.gpdb.StreamingDataSource("defaultcDQItu",
            db_instance_id=defaulth2ghc1.id,
            data_source_name="example",
            data_source_config=json.dumps({
                "brokers": "alikafka-post-cn-g4t3t4eod004-1-vpc.alikafka.aliyuncs.com:9092,alikafka-post-cn-g4t3t4eod004-2-vpc.alikafka.aliyuncs.com:9092,alikafka-post-cn-g4t3t4eod004-3-vpc.alikafka.aliyuncs.com:9092",
                "delimiter": "|",
                "format": "delimited",
                "topic": "ziyuan_example",
            }),
            data_source_type="kafka",
            data_source_description="example",
            service_id=default2d_usz_y.service_id)
        default = alicloud.gpdb.StreamingJob("default",
            account="example_001",
            dest_schema="public",
            mode="professional",
            job_name="example-kafka",
            job_description="example-kafka",
            dest_database="adb_sampledata_tpch",
            db_instance_id=defaulth2ghc1.id,
            dest_table="customer",
            data_source_id=defaultc_dq_itu.data_source_id,
            password="example_001",
            job_config=\"\"\"ATABASE: adb_sampledata_tpch
        USER: example_001
        PASSWORD: example_001
        HOST: gp-2zean69451zsjj139-master.gpdb.rds.aliyuncs.com
        PORT: 5432
        KAFKA:
          INPUT:
            SOURCE:
              BROKERS: alikafka-post-cn-3mp3t4ekq004-1-vpc.alikafka.aliyuncs.com:9092
              TOPIC: ziyuan_example
              FALLBACK_OFFSET: LATEST
            KEY:
              COLUMNS:
              - NAME: c_custkey
                TYPE: int
              FORMAT: delimited
              DELIMITED_OPTION:
                DELIMITER: \\'|\\'
            VALUE:
              COLUMNS:
              - NAME: c_comment
                TYPE: varchar
              FORMAT: delimited
              DELIMITED_OPTION:
                DELIMITER: \\'|\\'
            ERROR_LIMIT: 10
          OUTPUT:
            SCHEMA: public
            TABLE: customer
            MODE: MERGE
            MATCH_COLUMNS:
            - c_custkey
            ORDER_COLUMNS:
            - c_custkey
            UPDATE_COLUMNS:
            - c_custkey
            MAPPING:
            - NAME: c_custkey
              EXPRESSION: c_custkey
          COMMIT:
            MAX_ROW: 1000
            MINIMAL_INTERVAL: 1000
            CONSISTENCY: ATLEAST
          POLL:
            BATCHSIZE: 1000
            TIMEOUT: 1000
          PROPERTIES:
            group.id: ziyuan_example_01
        \"\"\")
        ```

        ## Import

        GPDB Streaming Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/streamingJob:StreamingJob example <db_instance_id>:<job_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account: The name of the database account.
        :param pulumi.Input[str] consistency: The delivery guarantee setting.
               
               Valid values:
               
               - ATLEAST
               - EXACTLY
        :param pulumi.Input[str] data_source_id: The data source ID.
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dest_columns: Target Field
        :param pulumi.Input[str] dest_database: The name of the destination database.
        :param pulumi.Input[str] dest_schema: Target Schema
        :param pulumi.Input[str] dest_table: The name of the destination table.
        :param pulumi.Input[int] error_limit_count: The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        :param pulumi.Input[str] fallback_offset: Automatic offset reset
        :param pulumi.Input[str] group_name: Group Name
        :param pulumi.Input[str] job_config: The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        :param pulumi.Input[str] job_description: The description of the job.
        :param pulumi.Input[str] job_name: The name of the job.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] match_columns: Match Field
        :param pulumi.Input[str] mode: The configuration mode. Valid values:
               
               1.  basic: In basic mode, you must configure the configuration parameters.
               
               2.  professional: In professional mode, you can submit a YAML configuration file.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_columns: Source Field
        :param pulumi.Input[bool] try_run: Specifies whether to test the real-time job. Valid values:
               
               - true
               - false
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] update_columns: Update Field
        :param pulumi.Input[str] write_mode: The write mode.
               
               Valid values:
               
               - insert
               - update
               - merge
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StreamingJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GPDB Streaming Job resource.

        Real-time data tasks.

        For information about GPDB Streaming Job and how to use it, see [What is Streaming Job](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.231.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_t_xqb15 = alicloud.vpc.Network("defaultTXqb15", cidr_block="192.168.0.0/16")
        defaulta_s_whb_t = alicloud.vpc.Switch("defaultaSWhbT",
            vpc_id=default_t_xqb15.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        defaulth2ghc1 = alicloud.gpdb.Instance("defaulth2ghc1",
            instance_spec="2C8G",
            description=name,
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            zone_id="cn-beijing-h",
            vswitch_id=defaulta_s_whb_t.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default_t_xqb15.id,
            db_instance_mode="StorageElastic",
            engine="gpdb")
        default2d_usz_y = alicloud.gpdb.StreamingDataService("default2dUszY",
            service_name="example",
            db_instance_id=defaulth2ghc1.id,
            service_description="example",
            service_spec="8")
        defaultc_dq_itu = alicloud.gpdb.StreamingDataSource("defaultcDQItu",
            db_instance_id=defaulth2ghc1.id,
            data_source_name="example",
            data_source_config=json.dumps({
                "brokers": "alikafka-post-cn-g4t3t4eod004-1-vpc.alikafka.aliyuncs.com:9092,alikafka-post-cn-g4t3t4eod004-2-vpc.alikafka.aliyuncs.com:9092,alikafka-post-cn-g4t3t4eod004-3-vpc.alikafka.aliyuncs.com:9092",
                "delimiter": "|",
                "format": "delimited",
                "topic": "ziyuan_example",
            }),
            data_source_type="kafka",
            data_source_description="example",
            service_id=default2d_usz_y.service_id)
        default = alicloud.gpdb.StreamingJob("default",
            account="example_001",
            dest_schema="public",
            mode="professional",
            job_name="example-kafka",
            job_description="example-kafka",
            dest_database="adb_sampledata_tpch",
            db_instance_id=defaulth2ghc1.id,
            dest_table="customer",
            data_source_id=defaultc_dq_itu.data_source_id,
            password="example_001",
            job_config=\"\"\"ATABASE: adb_sampledata_tpch
        USER: example_001
        PASSWORD: example_001
        HOST: gp-2zean69451zsjj139-master.gpdb.rds.aliyuncs.com
        PORT: 5432
        KAFKA:
          INPUT:
            SOURCE:
              BROKERS: alikafka-post-cn-3mp3t4ekq004-1-vpc.alikafka.aliyuncs.com:9092
              TOPIC: ziyuan_example
              FALLBACK_OFFSET: LATEST
            KEY:
              COLUMNS:
              - NAME: c_custkey
                TYPE: int
              FORMAT: delimited
              DELIMITED_OPTION:
                DELIMITER: \\'|\\'
            VALUE:
              COLUMNS:
              - NAME: c_comment
                TYPE: varchar
              FORMAT: delimited
              DELIMITED_OPTION:
                DELIMITER: \\'|\\'
            ERROR_LIMIT: 10
          OUTPUT:
            SCHEMA: public
            TABLE: customer
            MODE: MERGE
            MATCH_COLUMNS:
            - c_custkey
            ORDER_COLUMNS:
            - c_custkey
            UPDATE_COLUMNS:
            - c_custkey
            MAPPING:
            - NAME: c_custkey
              EXPRESSION: c_custkey
          COMMIT:
            MAX_ROW: 1000
            MINIMAL_INTERVAL: 1000
            CONSISTENCY: ATLEAST
          POLL:
            BATCHSIZE: 1000
            TIMEOUT: 1000
          PROPERTIES:
            group.id: ziyuan_example_01
        \"\"\")
        ```

        ## Import

        GPDB Streaming Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/streamingJob:StreamingJob example <db_instance_id>:<job_id>
        ```

        :param str resource_name: The name of the resource.
        :param StreamingJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StreamingJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account: Optional[pulumi.Input[str]] = None,
                 consistency: Optional[pulumi.Input[str]] = None,
                 data_source_id: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 dest_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dest_database: Optional[pulumi.Input[str]] = None,
                 dest_schema: Optional[pulumi.Input[str]] = None,
                 dest_table: Optional[pulumi.Input[str]] = None,
                 error_limit_count: Optional[pulumi.Input[int]] = None,
                 fallback_offset: Optional[pulumi.Input[str]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 job_config: Optional[pulumi.Input[str]] = None,
                 job_description: Optional[pulumi.Input[str]] = None,
                 job_name: Optional[pulumi.Input[str]] = None,
                 match_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 src_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 try_run: Optional[pulumi.Input[bool]] = None,
                 update_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 write_mode: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StreamingJobArgs.__new__(StreamingJobArgs)

            __props__.__dict__["account"] = account
            __props__.__dict__["consistency"] = consistency
            if data_source_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_source_id'")
            __props__.__dict__["data_source_id"] = data_source_id
            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            __props__.__dict__["dest_columns"] = dest_columns
            __props__.__dict__["dest_database"] = dest_database
            __props__.__dict__["dest_schema"] = dest_schema
            __props__.__dict__["dest_table"] = dest_table
            __props__.__dict__["error_limit_count"] = error_limit_count
            __props__.__dict__["fallback_offset"] = fallback_offset
            __props__.__dict__["group_name"] = group_name
            __props__.__dict__["job_config"] = job_config
            __props__.__dict__["job_description"] = job_description
            if job_name is None and not opts.urn:
                raise TypeError("Missing required property 'job_name'")
            __props__.__dict__["job_name"] = job_name
            __props__.__dict__["match_columns"] = match_columns
            __props__.__dict__["mode"] = mode
            __props__.__dict__["password"] = password
            __props__.__dict__["src_columns"] = src_columns
            __props__.__dict__["try_run"] = try_run
            __props__.__dict__["update_columns"] = update_columns
            __props__.__dict__["write_mode"] = write_mode
            __props__.__dict__["create_time"] = None
            __props__.__dict__["job_id"] = None
            __props__.__dict__["status"] = None
        super(StreamingJob, __self__).__init__(
            'alicloud:gpdb/streamingJob:StreamingJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account: Optional[pulumi.Input[str]] = None,
            consistency: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            data_source_id: Optional[pulumi.Input[str]] = None,
            db_instance_id: Optional[pulumi.Input[str]] = None,
            dest_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            dest_database: Optional[pulumi.Input[str]] = None,
            dest_schema: Optional[pulumi.Input[str]] = None,
            dest_table: Optional[pulumi.Input[str]] = None,
            error_limit_count: Optional[pulumi.Input[int]] = None,
            fallback_offset: Optional[pulumi.Input[str]] = None,
            group_name: Optional[pulumi.Input[str]] = None,
            job_config: Optional[pulumi.Input[str]] = None,
            job_description: Optional[pulumi.Input[str]] = None,
            job_id: Optional[pulumi.Input[str]] = None,
            job_name: Optional[pulumi.Input[str]] = None,
            match_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            mode: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            src_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            status: Optional[pulumi.Input[str]] = None,
            try_run: Optional[pulumi.Input[bool]] = None,
            update_columns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            write_mode: Optional[pulumi.Input[str]] = None) -> 'StreamingJob':
        """
        Get an existing StreamingJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account: The name of the database account.
        :param pulumi.Input[str] consistency: The delivery guarantee setting.
               
               Valid values:
               
               - ATLEAST
               - EXACTLY
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] data_source_id: The data source ID.
        :param pulumi.Input[str] db_instance_id: The instance ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dest_columns: Target Field
        :param pulumi.Input[str] dest_database: The name of the destination database.
        :param pulumi.Input[str] dest_schema: Target Schema
        :param pulumi.Input[str] dest_table: The name of the destination table.
        :param pulumi.Input[int] error_limit_count: The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        :param pulumi.Input[str] fallback_offset: Automatic offset reset
        :param pulumi.Input[str] group_name: Group Name
        :param pulumi.Input[str] job_config: The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        :param pulumi.Input[str] job_description: The description of the job.
        :param pulumi.Input[str] job_id: The job ID.
        :param pulumi.Input[str] job_name: The name of the job.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] match_columns: Match Field
        :param pulumi.Input[str] mode: The configuration mode. Valid values:
               
               1.  basic: In basic mode, you must configure the configuration parameters.
               
               2.  professional: In professional mode, you can submit a YAML configuration file.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_columns: Source Field
        :param pulumi.Input[str] status: Service status, value:
        :param pulumi.Input[bool] try_run: Specifies whether to test the real-time job. Valid values:
               
               - true
               - false
               
               Default value: false.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] update_columns: Update Field
        :param pulumi.Input[str] write_mode: The write mode.
               
               Valid values:
               
               - insert
               - update
               - merge
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StreamingJobState.__new__(_StreamingJobState)

        __props__.__dict__["account"] = account
        __props__.__dict__["consistency"] = consistency
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data_source_id"] = data_source_id
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["dest_columns"] = dest_columns
        __props__.__dict__["dest_database"] = dest_database
        __props__.__dict__["dest_schema"] = dest_schema
        __props__.__dict__["dest_table"] = dest_table
        __props__.__dict__["error_limit_count"] = error_limit_count
        __props__.__dict__["fallback_offset"] = fallback_offset
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["job_config"] = job_config
        __props__.__dict__["job_description"] = job_description
        __props__.__dict__["job_id"] = job_id
        __props__.__dict__["job_name"] = job_name
        __props__.__dict__["match_columns"] = match_columns
        __props__.__dict__["mode"] = mode
        __props__.__dict__["password"] = password
        __props__.__dict__["src_columns"] = src_columns
        __props__.__dict__["status"] = status
        __props__.__dict__["try_run"] = try_run
        __props__.__dict__["update_columns"] = update_columns
        __props__.__dict__["write_mode"] = write_mode
        return StreamingJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def account(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the database account.
        """
        return pulumi.get(self, "account")

    @property
    @pulumi.getter
    def consistency(self) -> pulumi.Output[Optional[str]]:
        """
        The delivery guarantee setting.

        Valid values:

        - ATLEAST
        - EXACTLY
        """
        return pulumi.get(self, "consistency")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> pulumi.Output[str]:
        """
        The data source ID.
        """
        return pulumi.get(self, "data_source_id")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[str]:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter(name="destColumns")
    def dest_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Target Field
        """
        return pulumi.get(self, "dest_columns")

    @property
    @pulumi.getter(name="destDatabase")
    def dest_database(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the destination database.
        """
        return pulumi.get(self, "dest_database")

    @property
    @pulumi.getter(name="destSchema")
    def dest_schema(self) -> pulumi.Output[Optional[str]]:
        """
        Target Schema
        """
        return pulumi.get(self, "dest_schema")

    @property
    @pulumi.getter(name="destTable")
    def dest_table(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the destination table.
        """
        return pulumi.get(self, "dest_table")

    @property
    @pulumi.getter(name="errorLimitCount")
    def error_limit_count(self) -> pulumi.Output[Optional[int]]:
        """
        The number of allowed error rows. Write failures occur when Kafka data does not match the destination table in AnalyticDB for PostgreSQL. If the specified value is exceeded, the job fails.
        """
        return pulumi.get(self, "error_limit_count")

    @property
    @pulumi.getter(name="fallbackOffset")
    def fallback_offset(self) -> pulumi.Output[Optional[str]]:
        """
        Automatic offset reset
        """
        return pulumi.get(self, "fallback_offset")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[Optional[str]]:
        """
        Group Name
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="jobConfig")
    def job_config(self) -> pulumi.Output[Optional[str]]:
        """
        The YAML configuration file of the job. This parameter must be specified when Mode is set to professional.
        """
        return pulumi.get(self, "job_config")

    @property
    @pulumi.getter(name="jobDescription")
    def job_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the job.
        """
        return pulumi.get(self, "job_description")

    @property
    @pulumi.getter(name="jobId")
    def job_id(self) -> pulumi.Output[str]:
        """
        The job ID.
        """
        return pulumi.get(self, "job_id")

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Output[str]:
        """
        The name of the job.
        """
        return pulumi.get(self, "job_name")

    @property
    @pulumi.getter(name="matchColumns")
    def match_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Match Field
        """
        return pulumi.get(self, "match_columns")

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Output[Optional[str]]:
        """
        The configuration mode. Valid values:

        1.  basic: In basic mode, you must configure the configuration parameters.

        2.  professional: In professional mode, you can submit a YAML configuration file.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        The password of the database account.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="srcColumns")
    def src_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Source Field
        """
        return pulumi.get(self, "src_columns")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Service status, value:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tryRun")
    def try_run(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to test the real-time job. Valid values:

        - true
        - false

        Default value: false.
        """
        return pulumi.get(self, "try_run")

    @property
    @pulumi.getter(name="updateColumns")
    def update_columns(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Update Field
        """
        return pulumi.get(self, "update_columns")

    @property
    @pulumi.getter(name="writeMode")
    def write_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The write mode.

        Valid values:

        - insert
        - update
        - merge
        """
        return pulumi.get(self, "write_mode")

